﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Diagnostics;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Infragistics.Portable.Components.UI;
using Infragistics.Win;
using Infragistics.Win.DataVisualization;

namespace WDC_ChrossharValues
{
    public partial class Form1 : Form
    {
        ColumnSeries columnSeries;
        LineSeries lineSeries;

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            DataTable categoryTable = CreateCategoryTable();
            CategoryDateTimeXAxis xAxis = new CategoryDateTimeXAxis();
            xAxis.DataSource = categoryTable;
            xAxis.DateTimeMemberPath = "Dates";

            NumericYAxis  yAxis = new NumericYAxis();
            yAxis.MinimumValue = 0;

            columnSeries = new ColumnSeries();
            columnSeries.DataSource = categoryTable;
            columnSeries.XAxis = xAxis;
            columnSeries.YAxis = yAxis;
            columnSeries.Title = "Column Series";
            columnSeries.ValueMemberPath = "Column Values";

            DataTable emptyTable = CreateEmptyTable();

            CategoryXAxis emptyXAxis = new CategoryXAxis();
            emptyXAxis.DataSource = emptyTable;
            emptyXAxis.Gap = 0;

            NumericYAxis emptyYAxis = new NumericYAxis();
            emptyYAxis.MinimumValue = 0;
            emptyYAxis.MaximumValue = 1;
            emptyYAxis.LabelsVisible = false;
            emptyYAxis.Visibility = Visibility.Collapsed;

            var emptySeries = InitEmptySeries(emptyTable, emptyXAxis, emptyYAxis);

            lineSeries = new LineSeries();
            lineSeries.XAxis = xAxis;
            lineSeries.YAxis = yAxis;
            lineSeries.DataSource = categoryTable;
            lineSeries.ValueMemberPath = "Line Values";
            lineSeries.Title = "Line Series";
            lineSeries.Thickness = 5;

            ultraDataChart1.Axes.Add(xAxis);
            ultraDataChart1.Axes.Add(yAxis);

            ultraDataChart1.Axes.Add(emptyXAxis);
            ultraDataChart1.Axes.Add(emptyYAxis);

            ultraDataChart1.Series.Add(emptySeries);
            ultraDataChart1.Series.Add(columnSeries);
            ultraDataChart1.Series.Add(lineSeries);

            ultraDataChart1.CrosshairVisibility = Visibility.Visible;

            columnSeries.TooltipContentUpdating += series_TooltipContentUpdating;
            emptySeries.TooltipContentUpdating += series_TooltipContentUpdating;
            lineSeries.TooltipContentUpdating += series_TooltipContentUpdating;
        }

        private static ColumnSeries InitEmptySeries(DataTable emptyTable, CategoryXAxis emptyXAxis, NumericYAxis emptyYAxis)
        {
            var emptySeries = new ColumnSeries();
            emptySeries.Title = "Empty";
            emptySeries.DataSource = emptyTable;
            emptySeries.ValueMemberPath = "Values";
            emptySeries.XAxis = emptyXAxis;
            emptySeries.YAxis = emptyYAxis;
            emptySeries.Brush = new SolidBrush(Color.Transparent);
            emptySeries.Outline = emptySeries.Brush;
            return emptySeries;
        }

        System.Windows.Forms.Control series_TooltipContentUpdating(object sender, ChartTooltipContentEventArgs e)
        {
            DataRowView row = null;
            string series;

            if (e.DataContext.Series.Title.ToString().Equals("Empty"))
            {
                series = "Column Series";
                row = columnSeries.GetItem(columnSeries.
                    ToWorldPosition(ultraDataChart1.PointToClient(Cursor.Position))) as DataRowView;
            }
            else
            {
                row = e.DataContext.Item as DataRowView;
                series = e.DataContext.Series.Title.ToString();
            }

            if (row != null)
            {
                int value = -1;

                switch (series)
                {
                    case "Column Series":
                        value = row.Row.Field<int>("Column Values");
                        break;

                    case "Line Series":
                        value = row.Row.Field<int>("Line Values");
                        break;
                }

                DateTime date = row.Row.Field<DateTime>("Dates");

                tooltipLabel.Text = String.Format("Series: {0}\nDate: {1}\nValue: {2}", series, date, value);
                return tooltipLabel;
            }


            return null;
        }

        private DataTable CreateCategoryTable()
        {
            DataTable dt = new DataTable();
            dt.Columns.Add("Dates", typeof(DateTime));
            dt.Columns.Add("Column Values", typeof(int));
            dt.Columns.Add("Line Values", typeof(int));

            dt.Rows.Add(new object[] { DateTime.Today, 200 });
            dt.Rows.Add(new object[] { DateTime.Today.AddDays(1), 280, 234});
            dt.Rows.Add(new object[] { DateTime.Today.AddDays(2), 160,123});
            dt.Rows.Add(new object[] { DateTime.Today.AddDays(3), 120,234});
            dt.Rows.Add(new object[] { DateTime.Today.AddDays(4), 221,123});
            dt.Rows.Add(new object[] { DateTime.Today.AddDays(5), 144,234});
            dt.Rows.Add(new object[] { DateTime.Today.AddDays(6), 198,189});
            dt.Rows.Add(new object[] { DateTime.Today.AddDays(7), 220,235});
            dt.Rows.Add(new object[] { DateTime.Today.AddDays(8), 245,343});
            dt.Rows.Add(new object[] { DateTime.Today.AddDays(9), 208,242});
            dt.Rows.Add(new object[] { DateTime.Today.AddDays(10), 180,289});
            dt.Rows.Add(new object[] { DateTime.Today.AddDays(11), 202,207});

            return dt;
        }

        private DataTable CreateEmptyTable()
        {
            DataTable dt = new DataTable();
            dt.Columns.Add("Label", typeof(string));
            dt.Columns.Add("Values", typeof(int));

            dt.Rows.Add(new object[] { "Empty", 1 });

            return dt;
        }

    }


}
